package com.ruoyi.mall.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.mall.mapper.MallGoodsFollowMapper;
import com.ruoyi.mall.domain.MallGoodsFollow;
import com.ruoyi.mall.service.IMallGoodsFollowService;

/**
 * 产品关注Service业务层处理
 * 
 * @author chang
 * @date 2021-11-25
 */
@Service
public class MallGoodsFollowServiceImpl implements IMallGoodsFollowService 
{
    @Autowired
    private MallGoodsFollowMapper mallGoodsFollowMapper;

    /**
     * 查询产品关注
     * 
     * @param id 产品关注主键
     * @return 产品关注
     */
    @Override
    public MallGoodsFollow selectMallGoodsFollowById(Long id)
    {
        return mallGoodsFollowMapper.selectMallGoodsFollowById(id);
    }

    /**
     * 查询产品关注列表
     * 
     * @param mallGoodsFollow 产品关注
     * @return 产品关注
     */
    @Override
    public List<MallGoodsFollow> selectMallGoodsFollowList(MallGoodsFollow mallGoodsFollow)
    {
        return mallGoodsFollowMapper.selectMallGoodsFollowList(mallGoodsFollow);
    }

    /**
     * 新增产品关注
     * 
     * @param mallGoodsFollow 产品关注
     * @return 结果
     */
    @Override
    public int insertMallGoodsFollow(MallGoodsFollow mallGoodsFollow)
    {
        return mallGoodsFollowMapper.insertMallGoodsFollow(mallGoodsFollow);
    }

    /**
     * 修改产品关注
     * 
     * @param mallGoodsFollow 产品关注
     * @return 结果
     */
    @Override
    public int updateMallGoodsFollow(MallGoodsFollow mallGoodsFollow)
    {
        return mallGoodsFollowMapper.updateMallGoodsFollow(mallGoodsFollow);
    }

    /**
     * 批量删除产品关注
     * 
     * @param ids 需要删除的产品关注主键
     * @return 结果
     */
    @Override
    public int deleteMallGoodsFollowByIds(Long[] ids)
    {
        return mallGoodsFollowMapper.deleteMallGoodsFollowByIds(ids);
    }

    /**
     * 删除产品关注信息
     * 
     * @param id 产品关注主键
     * @return 结果
     */
    @Override
    public int deleteMallGoodsFollowById(Long id)
    {
        return mallGoodsFollowMapper.deleteMallGoodsFollowById(id);
    }
}
