package com.ruoyi.mall.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.mall.domain.MallGoodsFollow;
import com.ruoyi.mall.service.IMallGoodsFollowService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 产品关注Controller
 * 
 * @author chang
 * @date 2021-11-25
 */
@RestController
@RequestMapping("/mall/mallGoodsFollow")
public class MallGoodsFollowController extends BaseController
{
    @Autowired
    private IMallGoodsFollowService mallGoodsFollowService;

    /**
     * 查询产品关注列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallGoodsFollow:list')")
    @GetMapping("/list")
    public TableDataInfo list(MallGoodsFollow mallGoodsFollow)
    {
        startPage();
        List<MallGoodsFollow> list = mallGoodsFollowService.selectMallGoodsFollowList(mallGoodsFollow);
        return getDataTable(list);
    }

    /**
     * 导出产品关注列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallGoodsFollow:export')")
    @Log(title = "产品关注", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(MallGoodsFollow mallGoodsFollow)
    {
        List<MallGoodsFollow> list = mallGoodsFollowService.selectMallGoodsFollowList(mallGoodsFollow);
        ExcelUtil<MallGoodsFollow> util = new ExcelUtil<MallGoodsFollow>(MallGoodsFollow.class);
        return util.exportExcel(list, "产品关注数据");
    }

    /**
     * 获取产品关注详细信息
     */
    @PreAuthorize("@ss.hasPermi('mall:mallGoodsFollow:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(mallGoodsFollowService.selectMallGoodsFollowById(id));
    }

    /**
     * 新增产品关注
     */
    @PreAuthorize("@ss.hasPermi('mall:mallGoodsFollow:add')")
    @Log(title = "产品关注", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MallGoodsFollow mallGoodsFollow)
    {
        return toAjax(mallGoodsFollowService.insertMallGoodsFollow(mallGoodsFollow));
    }

    /**
     * 修改产品关注
     */
    @PreAuthorize("@ss.hasPermi('mall:mallGoodsFollow:edit')")
    @Log(title = "产品关注", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MallGoodsFollow mallGoodsFollow)
    {
        return toAjax(mallGoodsFollowService.updateMallGoodsFollow(mallGoodsFollow));
    }

    /**
     * 删除产品关注
     */
    @PreAuthorize("@ss.hasPermi('mall:mallGoodsFollow:remove')")
    @Log(title = "产品关注", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(mallGoodsFollowService.deleteMallGoodsFollowByIds(ids));
    }
}
